@@ -1,6 +1,6 @@
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
- * Copyright 1998-2015 The OpenLDAP Foundation.
+ * Copyright 1998-2020 The OpenLDAP Foundation.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -13,10 +13,10 @@
  */
 
 static const char copyright[] =
-"Copyright 1998-2015 The OpenLDAP Foundation.  All rights reserved.\n"
+"Copyright 1998-2020 The OpenLDAP Foundation.  All rights reserved.\n"
 "COPYING RESTRICTIONS APPLY\n";
 
  const char __Version[] =
-"@(#) $OpenLDAP: ldapsearch 2.4.41 (" __DATE__ " " __TIME__ ") $\n"
-"\tclement@localhost.localdomain:/home/clement/build/BUILD/openldap-2.4.41/clients/tools\n";
+"@(#) $OpenLDAP: ldapsearch 2.4.49 (" __DATE__ " " __TIME__ ") $\n"
+"\tclement@kptn-centos6:/home/clement/build/BUILD/openldap-2.4.49/clients/tools\n";
 
